Boolean filter implementation for Cinder tables.
Provides boolean filtering with radio button inputs for true/false options.
Delegates rendering to Cinder.Filters.RadioGroup with hardcoded true/false options.
Boolean filter implementation for Cinder tables.
Provides boolean filtering with radio button inputs for true/false options.
Delegates rendering to Cinder.Filters.RadioGroup with hardcoded true/false options.