Cinder.Renderers.Grid (Cinder v0.12.1)

Copy Markdown View Source

Renderer for grid/card layout.

This module contains the render function for displaying data in a responsive grid format with sort controls rendered as a button group.

Summary

Functions

Renders the grid layout.

Functions

render(assigns)

Renders the grid layout.