Renderer for list layout.
This module contains the render function for displaying data in a vertical list format with sort controls rendered as a button group.
Summary
Functions
Renders the list layout.
Renderer for list layout.
This module contains the render function for displaying data in a vertical list format with sort controls rendered as a button group.
Renders the list layout.