Behaviour for Cinder theme modules.
This behaviour defines the interface that all theme modules must implement, whether they use the DSL or are simple theme modules.
Summary
Callbacks
Resolves the theme configuration into a map of CSS classes.
Behaviour for Cinder theme modules.
This behaviour defines the interface that all theme modules must implement, whether they use the DSL or are simple theme modules.
Resolves the theme configuration into a map of CSS classes.