Renderer for grid/card layout.
This module contains the render function for displaying data in a responsive grid format with sort controls rendered as a button group.
Summary
Functions
Renders the grid layout.
Renderer for grid/card layout.
This module contains the render function for displaying data in a responsive grid format with sort controls rendered as a button group.
Renders the grid layout.